@@ -42,22 +42,22 @@ class CFileParse:
 
 def get_status(lines: str) -> (TypeLine, str):
     reg = [
+        '^( ){0,}?\/\*(.*?\n{0,}){0,}\*\/',
+        '^( ){0,}?\/\/.*',
         '\w{1,}(\*){0,} (\*){0,}\w{1,}\(((void)|(\n{0,1} *\w{1,}(\*){0,} (\*){0,}\w{1,}(, {0,1}\n{0,1} *\w{1,}(\*){0,} (\*){0,}\w{1,}){0,3})\n{0,1} {0,})\)\n{\n(.*\n)*?}',
         ' {0,}#\w{1,}.*',
         '(typedef ){0,1}(struct )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
         '(typedef ){0,1}(enum )(\w{1,} ){0,1}{\n {4}\w{1,} \w{1,};(\n {4}\w{1,} \w{1,};){0,}\n}( \w{1,}){0,1};',
-        '(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};',
-        '^( ){0,}?\/\*(.*\n{0,}?){0,}?\*\/',
-        '^( ){0,}?\/\/'
+        '(static ){0,1}(const ){0,1}\w{1,} \*{0,}\w{1,}(\[[0-9]{0,}\]){0,1} = ((\w{0,})|({\n{0,1} {0,}\w{0,}(,\n{0,1} {0,}\w{0,}){0,})|)\n{0,1}}{0,1};'
     ]
     status = [
+        TypeLine.COMMENT,
+        TypeLine.COMMENT,
         TypeLine.FUNCTION,
         TypeLine.MACRO,
         TypeLine.STRUCT,
         TypeLine.ENUM,
-        TypeLine.GLOBAL,
-        TypeLine.COMMENT,
-        TypeLine.COMMENT,
+        TypeLine.GLOBAL
     ]
     for i in range(len(reg)):
         res = re.search(reg[i], lines, re.MULTILINE)
